@@ -122,7 +122,8 @@ steam_api_rehash(SteamApi *api)
 
     steam_http_cookies_set(api->http,
         STEAM_HTTP_PAIR("forceMobile", "1"),
-        STEAM_HTTP_PAIR("mobileClient", PACKAGE),
+        STEAM_HTTP_PAIR("mobileClient", STEAM_API_CLIENT),
+        STEAM_HTTP_PAIR("mobileClientVersion", STEAM_API_CLIENT_VERSION),
         STEAM_HTTP_PAIR("sessionid", api->sessid),
         NULL
     );
@@ -386,7 +387,7 @@ steam_api_cb_auth_finish(SteamApiReq *req, const json_value *json)
     const gchar *str;
 
     steam_http_cookies_parse_req(req->api->http, req->req);
-    str = g_hash_table_lookup(req->api->http->cookies, "sessionid");
+    str = steam_http_cookies_get(req->api->http, "sessionid");
 
     if (str == NULL) {
         g_set_error(&req->err, STEAM_API_ERROR, STEAM_API_ERROR_GENERAL,
@@ -546,7 +547,7 @@ steam_api_req_auth(SteamApiReq *req, const gchar *user, const gchar *pass,
         STEAM_HTTP_PAIR("captcha_text", captcha),
         STEAM_HTTP_PAIR("rsatimestamp", req->api->pktime),
         STEAM_HTTP_PAIR("loginfriendlyname", PACKAGE),
-        STEAM_HTTP_PAIR("oauth_client_id", STEAM_API_CLIENTID),
+        STEAM_HTTP_PAIR("oauth_client_id", STEAM_API_CLIENT_ID),
         STEAM_HTTP_PAIR("donotcache", ms),
         STEAM_HTTP_PAIR("remember_login", "true"),
         STEAM_HTTP_PAIR("oauth_scope", "read_profile write_profile "
@@ -1124,7 +1125,7 @@ steam_api_req_user_accept(SteamApiReq *req, SteamId id,
     g_return_if_fail(req != NULL);
 
     sct = steam_util_enum_ptr(enums, NULL, type);
-    srl = g_strconcat(req->api->info->profile, "/home_process/", NULL);
+    srl = steam_http_uri_join(req->api->info->profile, "home_process", NULL);
     url_set(&url, srl);
 
     STEAM_ID_STR(id, sid);
@@ -1204,7 +1205,7 @@ steam_api_req_user_ignore(SteamApiReq *req, SteamId id, gboolean ignore)
 
     act = ignore ? "ignore" : "unignore";
     user = g_strdup_printf("friends[%" STEAM_ID_FORMAT "]", id);
-    srl = g_strconcat(req->api->info->profile, "/friends/", NULL);
+    srl = steam_http_uri_join(req->api->info->profile, "friends", NULL);
     url_set(&url, srl);
 
     info = steam_user_info_new(id);
@@ -1309,7 +1310,7 @@ steam_api_req_user_info(SteamApiReq *req)
     }
 
     ght = g_hash_table_new(g_int64_hash, g_int64_equal);
-    gstr = g_string_sized_new(2048);
+    gstr = g_string_new(NULL);
 
     for (l = req->infr->head, i = 0; l != NULL; l = n) {
         info = l->data;
@@ -1406,19 +1407,14 @@ steam_api_req_user_info_nicks(SteamApiReq *req)
         return;
     }
 
-    srl = g_strconcat(info->profile, "/ajaxaliases/", NULL);
+    srl = steam_http_uri_join(info->profile, "ajaxaliases", NULL);
     url_set(&url, srl);
 
     req->punc = steam_api_cb_user_info_nicks;
     steam_api_req_init(req, url.host, url.file);
 
-    /* /ajaxaliases/ does not like Mobile mode */
-    g_hash_table_remove(req->api->http->cookies, "forceMobile");
-    g_hash_table_remove(req->api->http->cookies, "mobileClient");
-
     req->req->flags |= STEAM_HTTP_REQ_FLAG_POST;
     steam_http_req_send(req->req);
-    steam_api_rehash(req->api);
     g_free(srl);
 }
 
