@@ -945,13 +945,12 @@ G_MODULE_EXPORT void
 init_plugin(void);
 
 G_MODULE_EXPORT void
-init_plugin()
+init_plugin(void)
 {
     struct prpl *dpp;
 
     static const struct prpl pp = {
         .name = "steam",
-        .options = OPT_NOOTR,
         .init = steam_init,
         .login = steam_login,
         .logout = steam_logout,
@@ -981,3 +980,23 @@ init_plugin()
     dpp = g_memdup(&pp, sizeof pp);
     register_protocol(dpp);
 }
+
+#ifdef BITLBEE_ABI_VERSION_CODE
+G_MODULE_EXPORT struct plugin_info *
+init_plugin_info(void);
+
+G_MODULE_EXPORT struct plugin_info *
+init_plugin_info(void)
+{
+	static struct plugin_info info = {
+		BITLBEE_ABI_VERSION_CODE,
+		"steam",
+		PACKAGE_VERSION,
+		"Steam protocol plugin",
+		"James Geboski <jgeboski@gmail.com>",
+		PACKAGE_URL
+	};
+
+	return &info;
+}
+#endif /* BITLBEE_ABI_VERSION_CODE */
